### Name: auc.ci
### Title: Estimation of Confidence Intervals for Area Under the
###   Concentration Time Curve in Complete and Incomplete Data Designs
### Aliases: auc.ci auc.ssd.ci auc.batch.ci
### Keywords: misc

### ** Examples

## example from Nedelman et al. (1995)
m.030 <- c(391, 396, 649, 1990, 3290, 3820, 844, 1650, 75.7, 288)
f.030 <- c(353, 384, 625, 1410, 1020, 1500, 933, 1030, 0, 80.5)
m.100 <- c(1910, 2550, 4230, 5110, 7490, 13500, 4380, 5380, 260, 326)
f.100 <- c(2790, 3280, 4980, 7550, 5500, 6650, 2250, 3220, 213, 636)
time <- c(1, 1, 2, 2, 4, 4, 8, 8, 24, 24)

auc.ci(conc=m.030, time=time, method=c('z', 't'), design='ssd')
auc.ci(conc=f.030, time=time, method=c('z', 't'), design='ssd')

auc.ci(conc=m.100, time=time, method=c('z', 't'), design='ssd')
auc.ci(conc=f.100, time=time, method=c('z', 't'), design='ssd')

data <- data.frame(conc=c(m.030, f.030, m.100, f.100), 
                   time=rep(time, 4), 
                   sex=c(rep('m', 10), rep('f', 10), rep('m', 10), rep('f', 10)),
                   dose=c(rep(30, 20), rep(100, 20)))

# comparing the two dose levels
data$concadj <- data$conc / data$dose
auc.ci(conc=data$concadj, time=data$time, group=data$dose, method=c('z', 't'), design='ssd')

## caution this might take a few minutes
## comparing two dose level using stratified resampling per gender
set.seed(260151)
auc.ci(conc=data$concadj, time=data$time, group=data$dose, method='boott',
       strata=data$sex, design='ssd')

## example from Bailer (1988)
time <- c(rep(0,4), rep(1.5,4), rep(3,4), rep(5,4), rep(8,4))
grp1 <- c(0.0658, 0.0320, 0.0338, 0.0438, 0.0059, 0.0030, 0.0084,
          0.0080, 0.0000, 0.0017, 0.0028, 0.0055, 0.0000, 0.0037,
          0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000)

grp2 <- c(0.2287, 0.3824, 0.2402, 0.2373, 0.1252, 0.0446, 0.0638,
          0.0511, 0.0182, 0.0000, 0.0117, 0.0126, 0.0000, 0.0440,
          0.0039, 0.0040, 0.0000, 0.0000, 0.0000, 0.0000)

grp3 <- c(0.4285, 0.5180, 0.3690, 0.5428, 0.0983, 0.0928, 0.1128,
          0.1157, 0.0234, 0.0311, 0.0344, 0.0349, 0.0032, 0.0052,
          0.0049, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000)

auc.ci(conc=grp1, time=time, method='z', design='ssd')
auc.ci(conc=grp2, time=time, method='z', design='ssd')
auc.ci(conc=grp3, time=time, method='z', design='ssd')

data <- data.frame(conc=c(grp1, grp2, grp3), time=rep(time, 3),
                   group=c(rep(1, length(grp1)), rep(2, length(grp2)), rep(3, length(grp3))))

## function call with data frame using simultaneous confidence intervals based 
## on bonferroni adjustment
auc.ci(subset(data, group==1 | group==2)$conc, subset(data, group==1 | group==2)$time, 
       group=subset(data, group==1 | group==2)$group, method=c('z', 't'), 
       conf.level=1-0.05/3, design='ssd')
auc.ci(subset(data, group==1 | group==3)$conc, subset(data, group==1 | group==2)$time, 
       group=subset(data, group==1 | group==3)$group, method=c('z', 't'), 
       conf.level=1-0.05/3, design='ssd')
auc.ci(subset(data, group==2 | group==3)$conc, subset(data, group==1 | group==2)$time, 
       group=subset(data, group==2 | group==3)$group, method=c('z', 't'), 
       conf.level=1-0.05/3, design='ssd')

## a batch design example from Jaki and Wolfsegger (in press), originally in Holder et al. (1999).
conc<-list(batch1=c(0,0,0,1.75,2.2,1.58,4.63,2.99,1.52),batch2=c(3.03,1.98,2.22,3.34,1.3,1.22),
           batch3=c(3.54,2.84,2.55,0.3,0.0421,0.231))
time<-list(batch1=c(0,0,0,1,1,1,6,6,6),batch2=c(2,2,2,10,10,10),batch3=c(4,4,4,24,24,24))
auc.ci(conc,time,method=c('z','t'), design='batch')

## difference of two AUCs in batch design from Jaki and Wolfsegger (in press),
## originally in Holder et al. (1999).
conc<-list(batch1=c(0,0,0,0,0,0,1.75,2.2,1.58,3.21,2.01,2.73,4.63,2.99,1.52,3.25,3.31,2.22),
           batch2=c(3.03,1.98,2.22,3.76,3.91,4.37,3.34,1.3,1.22,1.66,6.83,2.98),
           batch3=c(3.54,2.84,2.55,2.14,4.03,2.78,0.3,0.0421,0.231,0.0294,1,0.29))
time<-list(batch1=c(rep(0,6),rep(1,6),rep(6,6)),batch2=c(rep(2,6),rep(10,6)),
           batch3=c(rep(4,6),rep(24,6)))
group<-list(batch1=c(1,1,1,2,2,2,1,1,1,2,2,2,1,1,1,2,2,2),
            batch2=c(1,1,1,2,2,2,1,1,1,2,2,2),
            batch3=c(1,1,1,2,2,2,1,1,1,2,2,2))
auc.ci(conc,time,group=group, design='batch')




