### Name: auc.test
### Title: Hypothesis testing for Area Under the Concentration Time Curve
###   in Complete and Incomplete Data Designs
### Aliases: auc.test auc.batch.test auc.ssd.test
### Keywords: misc

### ** Examples

## example from Nedelman et al. (1995) for a serial sampling design
m.030 <- c(391, 396, 649, 1990, 3290, 3820, 844, 1650, 75.7, 288)
f.030 <- c(353, 384, 625, 1410, 1020, 1500, 933, 1030, 0, 80.5)
m.100 <- c(1910, 2550, 4230, 5110, 7490, 13500, 4380, 5380, 260, 326)
f.100 <- c(2790, 3280, 4980, 7550, 5500, 6650, 2250, 3220, 213, 636)
time <- c(1, 1, 2, 2, 4, 4, 8, 8, 24, 24)

## two sided test
auc.test(conc=m.030, time=time, theta=60000, 
         alternative="two.sided", design="ssd")

## one sided test
auc.test(conc=m.030, time=time, theta=60000, 
         alternative="greater", design="ssd")

data <- data.frame(conc=c(m.030, f.030, m.100, f.100), 
                   time=rep(time,4), 
                   sex=c(rep("m", 10), rep("f", 10), rep("m", 10), rep("f", 10)),
                   dose=c(rep(30, 20), rep(100, 20)))

# comparing the two dose levels
data$concadj <- data$conc / data$dose
auc.test(conc=data$concadj, time=data$time, theta=0, group=data$dose, design="ssd")

## a batch design example from Jaki and Wolfsegger (in press), originally in Holder et al. (1999).
conc<-list(batch1=c(0,0,0,1.75,2.2,1.58,4.63,2.99,1.52),batch2=c(3.03,1.98,2.22,3.34,1.3,1.22),
           batch3=c(3.54,2.84,2.55,0.3,0.0421,0.231))
time<-list(batch1=c(rep(0,3),rep(1,3),rep(6,3)), batch2=c(rep(2,3),rep(10,3)),
           batch3=c(rep(4,3),rep(24,3)))
auc.test(conc, time, theta=100, design="batch")

## difference of two AUCs in batch design from Jaki and Wolfsegger (in press),
## originally in Holder et al. (1999).
conc<-list(batch1=c(0,0,0,0,0,0,1.75,2.2,1.58,3.21,2.01,2.73,4.63,2.99,1.52,3.25,3.31,2.22),
           batch2=c(3.03,1.98,2.22,3.76,3.91,4.37,3.34,1.3,1.22,1.66,6.83,2.98),
           batch3=c(3.54,2.84,2.55,2.14,4.03,2.78,0.3,0.0421,0.231,0.0294,1,0.29))
time<-list(batch1=c(rep(0,6),rep(1,6),rep(6,6)), batch2=c(rep(2,6),rep(10,6)),
           batch3=c(rep(4,6),rep(24,6)))
group<-list(batch1=c(1,1,1,2,2,2,1,1,1,2,2,2,1,1,1,2,2,2),
            batch2=c(1,1,1,2,2,2,1,1,1,2,2,2),
            batch3=c(1,1,1,2,2,2,1,1,1,2,2,2))
auc.test(conc, time, theta=0, group=group, design="batch")




