### Name: biexp
### Title: Two-Phase Half-Life Estimation by Biexponential Model
### Aliases: biexp
### Keywords: misc

### ** Examples

## example from Pinheiro J.C. and Bates D.M. (2000, page 279)
## dataset Indometh of package datasets
require(datasets)
time <- Indometh$time
conc <- Indometh$conc

# fitting on observed and log-scale
res1 <- biexp(conc=conc, time=time, log.scale=FALSE)
res2 <- biexp(conc=conc, time=time, log.scale=TRUE)

print(res1$parms)
print(res2$parms)

plot(res1, xlim=c(0, max(time)))
plot(res2, xlim=c(0, max(time)), add=TRUE, lty=2)
legend(x=5, y=2.5, lty=c(1,2), legend=c("fitted on observed scale", "fitted on log-scale"))

# get residuals using function nls with maxiter=1 and tol=Inf
parms.obs <- list(a1=res1$parms[3,1], b1=res1$parms[2,1], a2=res1$parms[3,2], b2=res1$parms[2,2])
parms.log <- list(a1=res2$parms[3,1], b1=res2$parms[2,1], a2=res2$parms[3,2], b2=res2$parms[2,2])

resid.obs <- nls(conc ~ a1*exp(-b1*time) + a2*exp(-b2*time), start=parms.obs, 
             control=nls.control(maxiter=1, tol=Inf))
resid.log <- nls(log(conc) ~ log(a1*exp(-b1*time) + a2*exp(-b2*time)), start=parms.log, 
             control=nls.control(maxiter=1, tol=Inf))

plot.new()
plot(x=c(0, max(time)), y=c(-1,1), type="n", xlab="Time", ylab="Residuals")
abline(h=0)
points(y=summary(resid.obs)$res, x=time, col="red")
points(y=summary(resid.log)$res, x=time, col="blue")
legend(x=0, y=1, pch=c(21,21), col=c("red","blue"), legend=c("fitted on observed scale", 
       "fitted on log-scale")) 

# see also function SSbiexp of package stats 
parms.ssbiexp <- as.list(coef(nls(conc ~ SSbiexp(time, a1, b1, a2, b2))))
parms.ssbiexp <- list(a1=parms.ssbiexp$a1, b1=exp(parms.ssbiexp$b1), a2=parms.ssbiexp$a2, 
                 b2=exp(parms.ssbiexp$b2))
print(unlist(parms.ssbiexp))
print(unlist(parms.obs))
print(unlist(parms.log))



