### Name: eqv.ssd
### Title: Establishing Bioequivalence in Serial Sampling Designs
### Aliases: eqv.ssd
### Keywords: misc

### ** Examples

## example from Nedelman et al. (1995)
m.030 <- c(391, 396, 649, 1990, 3290, 3820, 844, 1650, 75.7, 288)
f.030 <- c(353, 384, 625, 1410, 1020, 1500, 933, 1030, 0, 80.5)
m.100 <- c(1910, 2550, 4230, 5110, 7490, 13500, 4380, 5380, 260, 326)
f.100 <- c(2790, 3280, 4980, 7550, 5500, 6650, 2250, 3220, 213, 636)
time <- c(1, 1, 2, 2, 4, 4, 8, 8, 24, 24)

data <- data.frame(conc=c(m.030, f.030, m.100, f.100), 
                   time=rep(time, 4), 
                   sex=c(rep("m", 10), rep("f", 10), rep("m", 10), rep("f", 10)),
                   dose=c(rep(30, 20), rep(100, 20)))

data$concadj <- data$conc / data$dose
eqv.ssd(conc=data$concadj, time=data$time, group=data$dose, method="asymp")
eqv.ssd(conc=data$concadj, time=data$time, group=data$dose, method="fieller")

set.seed(310578)
eqv.ssd(conc=data$concadj, time=data$time, group=data$dose, method="boott", nsample=1E3)

set.seed(310578)
eqv.ssd(conc=data$concadj, time=data$time, group=data$dose, method="boott",
        strata=data$sex, nsample=1E3)



