### Name: lee
### Title: Two-Phase Half-Life Estimation by Linear Fitting
### Aliases: lee
### Keywords: misc

### ** Examples

## example for preparation 1 from Lee et al. (1990)
time <- c(0.5, 1.0, 4.0, 8.0, 12.0, 24.0)
conc <- c(75, 72, 61, 54, 36, 6)
res1 <- lee(conc=conc, time=time, method='ols', points=2, lt=TRUE)
res2 <- lee(conc=conc, time=time, method='ols', points=2, lt=FALSE)
plot(res1, log='y', ylim=c(1,100))
plot(res2, add=TRUE, lty=2)

## example for preparation 2 from Lee et al. (1990)
time <- c(0.5, 1.0, 2.0, 6.5, 8.0, 12.5, 24.0)
conc <- c(75, 55, 48, 51, 39, 9, 5)
res3 <- lee(conc=conc, time=time, method='ols', points=2, lt=FALSE)
print(res3$parms)
plot(res2, log='y', ylim=c(1,100), lty=1, pch=20)
plot(res3, add=TRUE, lty=2, pch=21)
legend(x=0, y=10, pch=c(20,21), lty=c(1,2), legend=c('Preperation 1','Preperation 2'))

## artificial examples
time <- c(5, 180,  360,  540,  720)/60
conc <- c(2.360, 0.061, 0.019, 0.012, 0.024)
res4 <- lee(conc=conc, time=time, method='lad', points=2, lt=FALSE)
print(res4$parms)
plot(res4)
plot(res4, log='y')

time <- seq(1:10)
conc <- c(1,2,3,4,5,5,4,3,2,1)
res5 <- lee(conc=conc, time=time, method='lad', points=2, lt=FALSE)
plot(res5, log='y', ylim=c(1,7), main='', xlab='', ylab='', pch=19)

## real life example
## dataset Indometh of package datasets
require(datasets)
res6 <- data.frame(matrix(ncol=3, nrow=length(unique(Indometh$Subject))))
colnames(res6) <- c('ID', 'initial', 'terminal')
row <- 1
for(i in unique(Indometh$Subject)){
   temp <- subset(Indometh, Subject==i)
   res6[row, 1] <- unique(temp$Subject)
   res6[row, c(2:3)] <- lee(conc=temp$conc, time=temp$time, method='lad')$parms[1,]
   row <- row + 1
}
print(res6)

# geometric means and corresponding two-sided CIs
exp(mean(log(res6$initial)))
exp(t.test(log(res6$initial), conf.level=0.95)$conf.int)

exp(mean(log(res6$terminal)))
exp(t.test(log(res6$terminal), conf.level=0.95)$conf.int)




